@@ -4,7 +4,7 @@
 
 plot.stslist.freq <- function(x, cpal = NULL, missing.color = NULL, pbarw = TRUE,
   ylab = NULL, yaxis = TRUE, xaxis = TRUE, xtlab = NULL, xtstep = NULL,
-  cex.axis = 1, cex.plot, ...) {
+  tick.last = NULL, cex.axis = 1, cex.plot, ...) {
 
   TraMineR.check.depr.args(alist(cex.axis = cex.plot))
 
@@ -23,6 +23,9 @@ plot.stslist.freq <- function(x, cpal = NULL, missing.color = NULL, pbarw = TRUE
 		## For sequence objects created with previous versions
 		else {xtstep <- 1}
 	}
+	if(is.null(tick.last)){
+		tick.last <- ifelse(!is.null(attr(x, "tick.last")), attr(x, "tick.last"), FALSE)
+	}
 
 	seql <- length(xtlab)
 
@@ -67,6 +70,7 @@ plot.stslist.freq <- function(x, cpal = NULL, missing.color = NULL, pbarw = TRUE
 	## Plotting the x axis
 	if (xaxis) {
 		tpos <- seq(1, seql, xtstep)
+    if (tick.last & tpos[length(tpos)] < seql) tpos <- c(tpos,seql)
 		axis(1, at=tpos-0.5, labels=xtlab[tpos], cex.axis=cex.axis)
 	}
 
@@ -112,4 +116,3 @@ plot.stslist.freq <- function(x, cpal = NULL, missing.color = NULL, pbarw = TRUE
 			las=1,
 			cex.axis=cex.axis)
 }
-
