@@ -17,6 +17,8 @@ seqplot <- function(seqdata, group = NULL, type = "i", main = NULL, cpal = NULL,
 	oolist <- list(...)
 
   	if ("sortv" %in% names(oolist)) {sortv <- oolist[["sortv"]]}
+  	leg.ncol <- if ("ncol" %in% names(oolist)) { oolist[["ncol"]] } else { NULL }
+    oolist <- oolist[names(oolist) != "ncol"]
 
     diss <- NULL
   	if ("diss" %in% names(oolist)) {
@@ -34,6 +36,12 @@ seqplot <- function(seqdata, group = NULL, type = "i", main = NULL, cpal = NULL,
   }
 
   if (type == "r") { # stuff moved here by GR 17.01.2018
+    ## For type="r" each group should have at least 2 cases
+    grp <- group
+    if (is.null(grp)) grp <- rep(1,nrow(seqdata))
+    if (any(xtabs( ~ group(grp)) < 2))
+      stop("For type = 'r', each group must have 2 or more cases. At least one group has only 1.", call.=FALSE)
+
 		if (is.null(diss)) {## (! "diss" %in% names(oolist)  && ! "dist.matrix" %in% names(oolist))){
       if (! "method" %in% names(oolist)){
 			  stop("For type = 'r', you must provide a distance matrix or a method to compute it", call.=FALSE)
@@ -260,7 +268,7 @@ seqplot <- function(seqdata, group = NULL, type = "i", main = NULL, cpal = NULL,
 		## nbstat <- nbstat+1
 		}
 
-		TraMineR.legend(legpos, ltext, cpal, cex=cex.legend, density=density, angle=angle)
+		TraMineR.legend(legpos, ltext, cpal, cex=cex.legend, density=density, angle=angle, leg.ncol=leg.ncol)
 	}
 
 	## Restoring graphical parameters
